import sys

# Parameter File Setup
######################
# required variables for this stage
# it is an error if these aren't defined.
req_params_file_vars = []

# this is the list of variables that might be defined that we should write 
# to the params file if they are defined AND the conditional expression 
# evaluates to True.
# the format of this data structure is
# [ [ parameter, conditional_expression ], ... ]
opt_params_file_vars =  [ ["antialias_iterations", "do_antialias"], 
						  ["verbose", "True" ],  
                          ["fastmarching_isovalue", "do_fastmarching"],
                          ["blur_sigma", "do_blur"], 
                          ["icp_iterations", "do_icp"] ]

# Commandline Setup
######################
# commandline options
# the format of this data structure is
# [ [command, [ enabling_expression ], [ dependencies ] ]
# So the command will be written to the commandline IF the 
# enabling expression is True AND the dependencies are defined.
# If the dependencies are not defined, we may print a warning message
# and not put the param to the commandline or alternately throw an error.
commandline_params = [ ["antialias", "do_antialias", ["antialias_iterations"] ],
                       ["fastmarching", "do_fastmarching", ["fastmarching_isovalue"] ],
                       ["blur", "do_blur", ["blur_sigma"] ],
                       ["icp", "do_icp", ["icp_iterations"] ]  ]

global command_name
if sys.platform == "win32":
	command_name = "ShapeWorksGroom.exe"
else:
	command_name = "ShapeWorksGroom"

def copy_stage_inputs( output_path ) :
	copy_outputs_from_stage( "ROI", output_path )

def build_output_path( ) :
	return working_dir_path

def build_stage_outputs_list( ) :
	
	# the outputs of the previous stage are the inputs to
	# this one....
	inputs = import_outputs_list( "ROI" )
	outputs = build_stage_outputs_from_inputs( 'Filter', inputs )
	
	return outputs

def build_params_list( ) :

	global inputs
	global outputs
	
	req_params_file_vars.append( "inputs" )
	inputs = import_outputs_list( "ROI" )
	
	req_params_file_vars.append( "outputs" )
	outputs = build_stage_outputs_from_inputs( 'Filter', inputs )

def update_state_stage_specific( file ) :

	file.write( "percent_complete = 100.0\n" )
	file.write( "is_running = False\n" )
	
def cleanup( ) :
	return

