import glob
import sys

# Parameter File Setup
######################
# required variables for this stage
# it is an error if these aren't defined.
req_params_file_vars = [ "number_of_particles", "iterations_per_split" ]

# this is the list of variables that might be defined that we should write 
# to the params file if they are defined AND the conditional expression 
# evaluates to True.
# the format of this data structure is
# [ [ parameter, conditional_expression ], ... ]
opt_params_file_vars =  [ [ "relative_weighting", "do_relative_weighting"] ,
						  [ "adaptivity_strength", "do_adaptivity_strength" ] ]

# Commandline Setup
######################
# commandline options
# the format of this data structure is
# [ [command, [ enabling_expression ], [ dependencies ] ]
# So the command will be written to the commandline IF the 
# enabling expression is True AND the dependencies are defined.
# If the dependencies are not defined, we may print a warning message
# and not put the param to the commandline or alternately throw an error.
commandline_params = [ ]

global command_name
if sys.platform == "win32":
	command_name = "ShapeWorksRun.exe"
else:
	command_name = "ShapeWorksRun"

Initialize_Output_Prefix = "Initialize"

def copy_stage_inputs( output_path ) :

	copy_outputs_from_stage( "Filter", output_path )
	if ( reuse_previous_results ) :
		copy_outputs_from_stage( "Initialize", output_path )

def build_stage_outputs_list( ) :
	# gather the outputs
	# this uses the global project_path... should probably be
	# redesigned :(
		
	outputs = glob.glob( os.path.join( working_dir_path,Initialize_Output_Prefix+'*' ) )
	#print("outputs: %s" % outputs)
	# as a final step, remove the path in front of the filename
	# to make it consistent with the other stages.
	outputs_tmp = []
	for path in outputs :
		outputs_tmp.append( os.path.basename( path ) )
		
	outputs = outputs_tmp
	return outputs

def build_output_path( ) :
	return working_dir_path


def build_params_list( ) :

	global inputs
	global point_files
	global output_points_prefix
	global output_transform_file

	req_params_file_vars.append( "inputs" )
	inputs = import_outputs_list( "Filter" )
	if ( reuse_previous_results ) :
		req_params_file_vars.append( "point_files" )
		point_files = build_stage_outputs_list( )

	req_params_file_vars.append( "output_points_prefix" )
	output_points_prefix = Initialize_Output_Prefix
	
	req_params_file_vars.append( "output_transform_file" )
	output_transform_file = Initialize_Output_Prefix + "_transform"

def update_state_stage_specific( file ) :

	file.write( "percent_complete = 100.0\n" )
	file.write( "is_running = False\n" )

def cleanup( ) :
	return


